@@ -2,7 +2,7 @@
 A TiddlyWeb plugin providing a multi-user TiddlyWiki environment.
 """
 
-__version__ = '0.21.0'
+__version__ = '0.22.0'
 
 
 def init(config):
@@ -12,6 +12,7 @@ def init(config):
     import tiddlywebplugins.status
     import tiddlywebplugins.atom
     import tiddlywebplugins.differ
+    import tiddlywebplugins.twimport
     from tiddlyweb.util import merge_config
     from tiddlywebwiki.config import config as twwconfig
 
@@ -20,3 +21,4 @@ def init(config):
     tiddlywebplugins.status.init(config)
     tiddlywebplugins.atom.init(config)
     tiddlywebplugins.differ.init(config)
+    tiddlywebplugins.twimport.init(config)
